@@ -1,6 +1,6 @@
 import json
 
-from vogeler.exceptions import VogelerException
+from vogeler.exceptions import VogelerClientException
 from vogeler.messaging import amqp
 
 class VogelerClient(object):
@@ -9,7 +9,8 @@ class VogelerClient(object):
             self.ch, self.queue = amqp.setup_client(kwargs['host'], kwargs['username'], kwargs['password'])
             self.callback_function = callback_function
         except:
-            raise VogelerException()
+            raise VogelerClientException("\
+                    Error connecting to %s as %s" % (kwargs['host'], kwargs['username']))
 
     def callback(self, msg):
         message = json.loads(msg.body)
@@ -21,7 +22,7 @@ class VogelerClient(object):
             print "Vogeler(Client) is starting up"
             self.ch.basic_consume(self.queue, callback=self.callback, no_ack=True)
         except:
-            raise VogelerException()
+            raise VogelerClientException("Error consuming queue")
 
         while self.ch.callbacks:
             self.ch.wait()
@@ -31,7 +32,10 @@ class VogelerClient(object):
         msg = amqp.amqp.Message(json.dumps(message))
         if durable == True:
             msg.properties['delivery_mode'] = 2
-        self.ch.basic_publish(msg, exchange=amqp.master_exchange)
+        try:
+            self.ch.basic_publish(msg, exchange=amqp.master_exchange)
+        except:
+            raise VogelerClientException("Error publishing message to queue")
 
     def close(self):
         self.ch.close()
